==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/ko/mail.php <==
<?php

return array(
    'a_user_canceled' => '사용자가 웹사이트에서 품목 요청을 취소했습니다',
    'a_user_requested' => '사용자가 웹사이트에서 품목을 요청했습니다',
    'accessory_name' => '액세서리 이름',
    'additional_notes' => '추가 참고 사항:',
    'admin_has_created' => ':web 웹사이트에서 관리자가 당신에게 계정을 생성했습니다.',
    'asset' => '자산:',
    'asset_name' => '자산명:',
    'asset_requested' => '자산 요청',
    'asset_tag' => '자산 태그:',
    'assigned_to' => '할당',
    'best_regards' => '감사합니다,',
    'canceled' => '취소됨',
    'checkin_date' => '반입 날짜',
    'checkout_date' => '반출 날짜',
    'click_to_confirm' => ':web 계정을 확인하려면 다음 링크를 클릭하세요:',
    'click_on_the_link_accessory' => '부속품을 받았다면 아래 링크를 클릭하세요.',
    'click_on_the_link_asset' => '자산을 받았다면 아래 링크를 클릭하세요.',
    'Confirm_Asset_Checkin' => 'Asset checkin confirmation',
    'Confirm_Accessory_Checkin' => 'Accessory checkin confirmation',
    'Confirm_accessory_delivery' => 'Accessory delivery confirmation',
    'Confirm_license_delivery' => '라이센스 전달 확인',
    'Confirm_asset_delivery' => 'Asset delivery confirmation',
    'Confirm_consumable_delivery' => 'Consumable delivery confirmation',
    'current_QTY' => '현재 수량',
    'Days' => '일',
    'days' => '일',
    'expecting_checkin_date' => '반입 예상 일:',
    'expires' => '만료',
    'Expiring_Assets_Report' => '만료 자산 보고서.',
    'Expiring_Licenses_Report' => '만료 라이선스 보고서.',
    'hello' => '안녕하세요',
    'hi' => '안녕하세요',
    'i_have_read' => '사용 조약을 읽고 동의 하며, 이 품목을 수령했습니다.',
    'item' => '품목:',
    'Item_Request_Canceled' => '품목 요청 취소됨',
    'Item_Requested' => '품목 요청',
    'link_to_update_password' => ':web 비밀번호를 수정하려면 다음 링크를 클릭하세요:',
    'login_first_admin' => '아래의 자격 증명을 사용하여 새 Snipe-IT 설치본에 로그인 하세요:',
    'login' => '로그인:',
    'Low_Inventory_Report' => '재고 부족 보고서',
    'min_QTY' => '최소 수량',
    'name' => '이름',
    'new_item_checked' => '당신의 이름으로 새 품목이 반출 되었습니다, 이하는 상세입니다.',
    'password' => '비밀번호:',
    'password_reset' => '비밀번호 재설정',

    'read_the_terms' => '아래의 이용 약관을 읽어 보시기 바랍니다.',
    'read_the_terms_and_click' => '아래의 이용약관을 읽어보시고, 약관에 동의하시고, 자산을 받았다면, 아래의 링크를 클릭하여 확인해 주세요.',
    'requested' => '요청됨:',
    'reset_link' => '비밀번호 재설정 링크',
    'reset_password' => '이곳을 눌러 비밀번호를 재설정:',
    'serial' => '시리얼',
    'supplier' => '공급자',
    'tag' => '태그',
    'test_email' => 'Snipe-IT에서 테스트 이메일',
    'test_mail_text' => '이것은 Snipe-IT 자산 관리 시스템에서 온 테스트 입니다. 이 것을 받았다면, 메일은 동작중입니다 :)',
    'the_following_item' => '다음의 품목들이 반입되었습니다: ',
    'low_inventory_alert' => '최소 보유량보다 낮거나 소진될 수 있는 품목이 :count 개 있습니다.|최소 보유량보다 낮거나 소진될 수 있는 품목이 :count 개 있습니다.',
    'assets_warrantee_alert' => '다음 :threshold 일 이내에 보증 기간이 만료되는 자산이 :count 개 있습니다.|다음 :threshold 일 이내에 보증 기간이 만료되는 자산들이 :count 개 있습니다.',
    'license_expiring_alert' => '다음 :threshold 일 내에 만료되는 라이선스가 :count 개 있습니다.|다음 :threshold 일 내에 만료되는 라이선스가 :count 개 있습니다.',
    'to_reset' => ':web 비밀번호를 재설정 하려면, 이 양식을 작성하세요:',
    'type' => '유형',
    'upcoming-audits' => 'There is :count asset that is coming up for audit within :threshold days.|There are :count assets that are coming up for audit within :threshold days.',
    'user' => '사용자',
    'username' => '사용자명',
    'welcome' => '환영합니다 :name',
    'welcome_to' => '환영합니다 :web!',
    'your_credentials' => '당신의 Snipe-IT 인증들',
    'Accessory_Checkin_Notification' => 'Accessory checked in',
    'Asset_Checkin_Notification' => 'Asset checked in',
    'License_Checkin_Notification' => '라이센스 확인 됨.',
    'Expected_Checkin_Report' => 'Expected asset checkin report',
    'Expected_Checkin_Notification' => 'Reminder: :name checkin deadline approaching',
    'Expected_Checkin_Date' => 'An asset checked out to you is due to be checked back in on :date',
    'your_assets' => '자산 확인'
);

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/ko/mail.php <==
<?php

return [
    'a_user_canceled' => '사용자가 웹사이트에서 품목 요청을 취소했습니다',
    'a_user_requested' => '사용자가 웹사이트에서 품목을 요청했습니다',
    'accessory_name' => '액세서리 이름',
    'additional_notes' => '추가 참고 사항:',
    'admin_has_created' => ':web 웹사이트에서 관리자가 당신에게 계정을 생성했습니다.',
    'asset' => '자산:',
    'asset_name' => '자산명:',
    'asset_requested' => '자산 요청',
    'asset_tag' => '자산 태그',
    'assigned_to' => '할당',
    'best_regards' => '감사합니다,',
    'canceled' => '취소됨',
    'checkin_date' => '반입 날짜',
    'checkout_date' => '반출 날짜',
    'click_to_confirm' => ':web 계정을 확인하려면 다음 링크를 클릭하세요:',
    'click_on_the_link_accessory' => '부속품을 받았다면 아래 링크를 클릭하세요.',
    'click_on_the_link_asset' => '자산을 받았다면 아래 링크를 클릭하세요.',
    'Confirm_Asset_Checkin' => '자산 반입 확인',
    'Confirm_Accessory_Checkin' => '부속품 반입 확인',
    'Confirm_accessory_delivery' => '액세서리 지급 확인',
    'Confirm_license_delivery' => '라이센스 전달 확인',
    'Confirm_asset_delivery' => '자산 지급 확인',
    'Confirm_consumable_delivery' => 'Consumable delivery confirmation',
    'current_QTY' => '현재 수량',
    'Days' => '일',
    'days' => '일',
    'expecting_checkin_date' => '반입 예상 일:',
    'expires' => '만료',
    'Expiring_Assets_Report' => '만료 자산 보고서.',
    'Expiring_Licenses_Report' => '만료 라이선스 보고서.',
    'hello' => '안녕하세요',
    'hi' => '안녕하세요',
    'i_have_read' => '사용 조약을 읽고 동의 하며, 이 품목을 수령했습니다.',
    'item' => '품목:',
    'Item_Request_Canceled' => '품목 요청 취소됨',
    'Item_Requested' => '품목 요청',
    'link_to_update_password' => ':web 비밀번호를 수정하려면 다음 링크를 클릭하세요:',
    'login_first_admin' => '아래의 자격 증명을 사용하여 새 Snipe-IT 설치본에 로그인 하세요:',
    'login' => '로그인:',
    'Low_Inventory_Report' => '재고 부족 보고서',
    'min_QTY' => '최소 수량',
    'name' => '이름',
    'new_item_checked' => '당신의 이름으로 새 품목이 반출 되었습니다, 이하는 상세입니다.',
    'password' => '비밀번호:',
    'password_reset' => '비밀번호 재설정',

    'read_the_terms' => '아래의 이용 약관을 읽어 보시기 바랍니다.',
    'read_the_terms_and_click' => '아래의 이용약관을 읽어보시고, 약관에 동의하시고, 자산을 받았다면, 아래의 링크를 클릭하여 확인해 주세요.',
    'requested' => '요청됨:',
    'reset_link' => '비밀번호 재설정 링크',
    'reset_password' => '이곳을 눌러 비밀번호를 재설정:',
    'serial' => '시리얼',
    'supplier' => '공급자',
    'tag' => '태그',
    'test_email' => 'Snipe-IT에서 테스트 이메일',
    'test_mail_text' => '이것은 Snipe-IT 자산 관리 시스템에서 온 테스트 입니다. 이 것을 받았다면, 메일은 동작중입니다 :)',
    'the_following_item' => '다음의 품목들이 반입되었습니다: ',
    'low_inventory_alert' => '최소 보유량보다 낮거나 소진될 수 있는 품목이 :count 개 있습니다.|최소 보유량보다 낮거나 소진될 수 있는 품목이 :count 개 있습니다.',
    'assets_warrantee_alert' => 'There is :count asset with a warranty expiring in the next :threshold days.|There are :count assets with warranties expiring in the next :threshold days.',
    'license_expiring_alert' => '다음 :threshold 일 내에 만료되는 라이선스가 :count 개 있습니다.|다음 :threshold 일 내에 만료되는 라이선스가 :count 개 있습니다.',
    'to_reset' => ':web 비밀번호를 재설정 하려면, 이 양식을 작성하세요:',
    'type' => '유형',
    'upcoming-audits' => 'There is :count asset that is coming up for audit within :threshold days.|There are :count assets that are coming up for audit within :threshold days.',
    'user' => '사용자',
    'username' => '사용자명',
    'welcome' => '환영합니다 :name',
    'welcome_to' => '환영합니다 :web!',
    'your_credentials' => '당신의 Snipe-IT 인증들',
    'Accessory_Checkin_Notification' => '부속품 반입 됨',
    'Asset_Checkin_Notification' => '자산 반입 됨',
    'License_Checkin_Notification' => '라이센스 확인 됨.',
    'Expected_Checkin_Report' => 'Expected asset checkin report',
    'Expected_Checkin_Notification' => 'Reminder: :name checkin deadline approaching',
    'Expected_Checkin_Date' => 'An asset checked out to you is due to be checked back in on :date',
    'your_assets' => '자산 확인',
];
